@@ -25,8 +25,9 @@ GisTools allows some of the following operations:
 """
 
 # __all__ = []
+from shapely.geometry import LineString, MultiLineString, Polygon, MultiPolygon, Point, MultiPoint
 
-__version__ = '0.16.4'
+__version__ = '0.16.23'
 __author__ = 'Benjamin Pillot'
 __copyright__ = 'Copyright 2020, Benjamin Pillot'
 __email__ = 'benjaminpillot@riseup.net'
@@ -36,3 +37,7 @@ __licence__ = "GNU GPL v3.0"
 # from gistools.raster import *
 # from gistools.network import *
 # from gistools.stats import *
+
+
+GEOMETRY_CLASS = {'linestring': (LineString, MultiLineString), 'polygon': (Polygon, MultiPolygon),
+                  'point': (Point, MultiPoint)}
